@@ -559,13 +559,13 @@ class EsHelper:
         if method in ["get", "post", "put", "delete"]:
             res = None
             if method == "get":
-                res = self.pool.format_es_get(url, params)
+                res = self.pool.format_es_get(url=url, params=params)
             elif method == "post":
-                res = self.pool.format_es_post(url, body, params)
+                res = self.pool.format_es_post(url=url, body=body, params=params)
             elif method == "put":
-                res = self.pool.format_es_put(url, body, params)
+                res = self.pool.format_es_put(url=url, body=body, params=params)
             elif method == "delete":
-                res = self.pool.format_es_delete(url, body, params)
+                res = self.pool.format_es_delete(url=url, params=params)
             return res
         else:
             raise Exception(f"method={method} is not supported")
